.. pyvcloud documentation master file, created by
   sphinx-quickstart on Wed Mar 14 14:04:39 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Python SDK for VMware vCloud Director
=====================================

Welcome to the documentation pages for pyvcloud. This project is
maintained by `VMware, Inc. <https://www.vmware.com>`_

.. toctree::
   :maxdepth: 2

   Python Documentation <pyvcloud>

Code and Module Indexes
=======================

* :ref:`genindex`
* :ref:`modindex`
